@@ -16,7 +16,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from typing import Optional, Callable, Any
+from typing import Any, Callable, Optional
 
 from gvm.connections import GvmConnection
 
