@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2019-2021 Greenbone Networks GmbH
+# Copyright (C) 2019-2022 Greenbone Networks GmbH
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -19,21 +19,20 @@
 """
 Module for communication with gvmd
 """
-from typing import Any, Optional, Callable, Union
+from types import TracebackType
+from typing import Any, Callable, Optional, Type, Union
 
 from gvm.errors import GvmError
-
-from gvm.protocols.base import GvmProtocol, GvmConnection
-
+from gvm.protocols.base import GvmConnection, GvmProtocol
 from gvm.protocols.gmpv208 import Gmp as Gmpv208
 from gvm.protocols.gmpv214 import Gmp as Gmpv214
-from gvm.protocols.gmpv2110 import Gmp as Gmpv2110
-
+from gvm.protocols.gmpv224 import Gmp as Gmpv224
 from gvm.transforms import EtreeCheckCommandTransform
-
 from gvm.xml import XmlCommand
 
-SUPPORTED_GMP_VERSIONS = Union[Gmpv208, Gmpv214]  # pylint: disable=invalid-name
+SUPPORTED_GMP_VERSIONS = Union[  # pylint: disable=invalid-name
+    Gmpv208, Gmpv214, Gmpv224
+]
 
 
 class Gmp(GvmProtocol):
@@ -83,11 +82,11 @@ class Gmp(GvmProtocol):
         resp = self._send_xml_command(XmlCommand("get_version"))
         self.disconnect()
 
-        version_el = resp.find('version')
+        version_el = resp.find("version")
         if version_el is None:
             raise GvmError(
-                'Invalid response from manager daemon while requesting the '
-                'version information.'
+                "Invalid response from manager daemon while requesting the "
+                "version information."
             )
 
         return version_el.text
@@ -96,26 +95,35 @@ class Gmp(GvmProtocol):
         """Determine supported GMP version of the remote daemon and return a
         corresponding Gmp class instance
         """
-        version_str = self.determine_remote_gmp_version().split('.', 1)
+        version_str = self.determine_remote_gmp_version().split(".", 1)
         major_version = int(version_str[0])
         minor_version = int(version_str[1])
         if major_version == 20:
             gmp_class = Gmpv208
         elif major_version == 21 and minor_version == 4:
             gmp_class = Gmpv214
-        elif major_version == 21 and minor_version == 10:
-            gmp_class = Gmpv2110
+        elif major_version == 22 and minor_version == 4:
+            gmp_class = Gmpv224
         else:
             raise GvmError(
-                'Remote manager daemon uses an unsupported version of GMP. '
-                f'The GMP version was {major_version}.{minor_version}'
+                "Remote manager daemon uses an unsupported version of GMP. "
+                f"The GMP version was {major_version}.{minor_version}"
             )
 
         return gmp_class(self._connection, transform=self._gmp_transform)
 
     def __enter__(self):
-        gmp = self.determine_supported_gmp()
+        self._gmp = self.determine_supported_gmp()
 
-        gmp.connect()
+        self._gmp.connect()
 
-        return gmp
+        return self._gmp
+
+    def __exit__(
+        self,
+        exc_type: Optional[Type[BaseException]],
+        exc_value: Optional[BaseException],
+        traceback: Optional[TracebackType],
+    ) -> Any:
+        self._gmp.disconnect()
+        self._gmp = None
