@@ -17,13 +17,14 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from typing import Any, List, Optional, Tuple
+
 from lxml.etree import XMLSyntaxError
 
-from gvm.errors import RequiredArgument, InvalidArgument, InvalidArgumentType
-from gvm.utils import add_filter, to_base64, to_bool, is_list_like
+from gvm.errors import InvalidArgument, InvalidArgumentType, RequiredArgument
+from gvm.utils import add_filter, is_list_like, to_base64, to_bool
 from gvm.xml import XmlCommand
 
-_EMPTY_POLICY_ID = '085569ce-73ed-11df-83c3-002264764cea'
+_EMPTY_POLICY_ID = "085569ce-73ed-11df-83c3-002264764cea"
 
 
 class PoliciesMixin:
@@ -38,7 +39,7 @@ class PoliciesMixin:
         """
         if not policy_id:
             raise RequiredArgument(
-                function=self.clone_policy.__name__, argument='policy_id'
+                function=self.clone_policy.__name__, argument="policy_id"
             )
 
         cmd = XmlCommand("create_config")
@@ -65,7 +66,7 @@ class PoliciesMixin:
             policy_id = _EMPTY_POLICY_ID
         if not name:
             raise RequiredArgument(
-                function=self.create_policy.__name__, argument='name'
+                function=self.create_policy.__name__, argument="name"
             )
 
         if comment is not None:
@@ -85,7 +86,7 @@ class PoliciesMixin:
         """
         if not policy_id:
             raise RequiredArgument(
-                function=self.delete_policy.__name__, argument='policy_id'
+                function=self.delete_policy.__name__, argument="policy_id"
             )
 
         cmd = XmlCommand("delete_config")
@@ -158,7 +159,7 @@ class PoliciesMixin:
         """
         if not policy_id:
             raise RequiredArgument(
-                function=self.get_policy.__name__, argument='policy_id'
+                function=self.get_policy.__name__, argument="policy_id"
             )
 
         cmd = XmlCommand("get_configs")
@@ -186,7 +187,7 @@ class PoliciesMixin:
         """
         if not policy:
             raise RequiredArgument(
-                function=self.import_policy.__name__, argument='policy'
+                function=self.import_policy.__name__, argument="policy"
             )
 
         cmd = XmlCommand("create_config")
@@ -195,7 +196,7 @@ class PoliciesMixin:
             cmd.append_xml_str(policy)
         except XMLSyntaxError as e:
             raise InvalidArgument(
-                function=self.import_policy.__name__, argument='policy'
+                function=self.import_policy.__name__, argument="policy"
             ) from e
 
         return self._send_xml_command(cmd)
@@ -220,19 +221,19 @@ class PoliciesMixin:
         if not policy_id:
             raise RequiredArgument(
                 function=self.modify_policy_set_nvt_preference.__name__,
-                argument='policy_id',
+                argument="policy_id",
             )
 
         if not nvt_oid:
             raise RequiredArgument(
                 function=self.modify_policy_set_nvt_preference.__name__,
-                argument='nvt_oid',
+                argument="nvt_oid",
             )
 
         if not name:
             raise RequiredArgument(
                 function=self.modify_policy_set_nvt_preference.__name__,
-                argument='name',
+                argument="name",
             )
 
         cmd = XmlCommand("modify_config")
@@ -258,13 +259,13 @@ class PoliciesMixin:
         if not policy_id:
             raise RequiredArgument(
                 function=self.modify_policy_set_name.__name__,
-                argument='policy_id',
+                argument="policy_id",
             )
 
         if not name:
             raise RequiredArgument(
                 function=self.modify_policy_set_name.__name__,
-                argument='name',
+                argument="name",
             )
 
         cmd = XmlCommand("modify_config")
@@ -288,7 +289,7 @@ class PoliciesMixin:
         if not policy_id:
             raise RequiredArgument(
                 function=self.modify_policy_set_comment.__name__,
-                argument='policy_id',
+                argument="policy_id",
             )
 
         cmd = XmlCommand("modify_config")
@@ -314,13 +315,13 @@ class PoliciesMixin:
         if not policy_id:
             raise RequiredArgument(
                 function=(self.modify_policy_set_scanner_preference.__name__),
-                argument='policy_id',
+                argument="policy_id",
             )
 
         if not name:
             raise RequiredArgument(
                 function=(self.modify_policy_set_scanner_preference.__name__),
-                argument='name argument',
+                argument="name argument",
             )
 
         cmd = XmlCommand("modify_config")
@@ -351,20 +352,20 @@ class PoliciesMixin:
         if not policy_id:
             raise RequiredArgument(
                 function=self.modify_policy_set_nvt_selection.__name__,
-                argument='policy_id',
+                argument="policy_id",
             )
 
         if not family:
             raise RequiredArgument(
                 function=self.modify_policy_set_nvt_selection.__name__,
-                argument='family argument',
+                argument="family argument",
             )
 
         if not is_list_like(nvt_oids):
             raise InvalidArgumentType(
                 function=self.modify_policy_set_nvt_selection.__name__,
-                argument='nvt_oids',
-                arg_type='list',
+                argument="nvt_oids",
+                arg_type="list",
             )
 
         cmd = XmlCommand("modify_config")
@@ -401,14 +402,14 @@ class PoliciesMixin:
         if not policy_id:
             raise RequiredArgument(
                 function=self.modify_policy_set_family_selection.__name__,
-                argument='policy_id',
+                argument="policy_id",
             )
 
         if not is_list_like(families):
             raise InvalidArgumentType(
                 function=self.modify_policy_set_family_selection.__name__,
-                argument='families',
-                arg_type='list',
+                argument="families",
+                arg_type="list",
             )
 
         cmd = XmlCommand("modify_config")
@@ -431,8 +432,8 @@ class PoliciesMixin:
             ):
                 raise InvalidArgumentType(
                     function=(self.modify_policy_set_family_selection.__name__),
-                    argument='families',
-                    arg_type='[tuple(str, bool, bool)]',
+                    argument="families",
+                    arg_type="[tuple(str, bool, bool)]",
                 )
 
             _xmlfamily.add_element("all", to_bool(family[2]))
