@@ -18,6 +18,7 @@
 
 from enum import Enum
 from typing import Any, Optional, Union
+
 from lxml.etree import XMLSyntaxError
 
 from gvm.errors import InvalidArgument, RequiredArgument
@@ -28,25 +29,25 @@ from gvm.xml import XmlCommand
 class ReportFormatType(Enum):
     """Enum for builtin report formats"""
 
-    ANONYMOUS_XML = '5057e5cc-b825-11e4-9d0e-28d24461215b'
-    ARF = '910200ca-dc05-11e1-954f-406186ea4fc5'
-    CPE = '5ceff8ba-1f62-11e1-ab9f-406186ea4fc5'
+    ANONYMOUS_XML = "5057e5cc-b825-11e4-9d0e-28d24461215b"
+    ARF = "910200ca-dc05-11e1-954f-406186ea4fc5"
+    CPE = "5ceff8ba-1f62-11e1-ab9f-406186ea4fc5"
     CSV_HOSTS = '9087b18c-626c-11e3-8892-406186ea4fc5"'
-    CSV_RESULTS = 'c1645568-627a-11e3-a660-406186ea4fc5'
-    GCR_PDF = 'dc51a40a-c022-11e9-b02d-3f7ca5bdcb11'
-    GSR_HTML = 'ffa123c9-a2d2-409e-bbbb-a6c1385dbeaa'
-    GSR_PDF = '35ba7077-dc85-42ef-87c9-b0eda7e903b6'
-    GXCR_PDF = 'f0d348de-c022-11e9-bc4c-4bf1d5e1a8ca'
-    GXR_PDF = 'ebbc7f34-8ae5-11e1-b07b-001f29eadec8'
-    ITG = '77bd6c4a-1f62-11e1-abf0-406186ea4fc5'
-    LATEX = 'a684c02c-b531-11e1-bdc2-406186ea4fc5'
-    NBE = '9ca6fe72-1f62-11e1-9e7c-406186ea4fc5'
-    PDF = 'c402cc3e-b531-11e1-9163-406186ea4fc5'
-    SVG = '9e5e5deb-879e-4ecc-8be6-a71cd0875cdd'
-    TXT = 'a3810a62-1f62-11e1-9219-406186ea4fc5'
-    VERINICE_ISM = 'c15ad349-bd8d-457a-880a-c7056532ee15'
-    VERINICE_ITG = '50c9950a-f326-11e4-800c-28d24461215b'
-    XML = 'a994b278-1f62-11e1-96ac-406186ea4fc5'
+    CSV_RESULTS = "c1645568-627a-11e3-a660-406186ea4fc5"
+    GCR_PDF = "dc51a40a-c022-11e9-b02d-3f7ca5bdcb11"
+    GSR_HTML = "ffa123c9-a2d2-409e-bbbb-a6c1385dbeaa"
+    GSR_PDF = "35ba7077-dc85-42ef-87c9-b0eda7e903b6"
+    GXCR_PDF = "f0d348de-c022-11e9-bc4c-4bf1d5e1a8ca"
+    GXR_PDF = "ebbc7f34-8ae5-11e1-b07b-001f29eadec8"
+    ITG = "77bd6c4a-1f62-11e1-abf0-406186ea4fc5"
+    LATEX = "a684c02c-b531-11e1-bdc2-406186ea4fc5"
+    NBE = "9ca6fe72-1f62-11e1-9e7c-406186ea4fc5"
+    PDF = "c402cc3e-b531-11e1-9163-406186ea4fc5"
+    SVG = "9e5e5deb-879e-4ecc-8be6-a71cd0875cdd"
+    TXT = "a3810a62-1f62-11e1-9219-406186ea4fc5"
+    VERINICE_ISM = "c15ad349-bd8d-457a-880a-c7056532ee15"
+    VERINICE_ITG = "50c9950a-f326-11e4-800c-28d24461215b"
+    XML = "a994b278-1f62-11e1-96ac-406186ea4fc5"
 
     @classmethod
     def from_string(
@@ -58,10 +59,10 @@ class ReportFormatType(Enum):
             return None
 
         try:
-            return cls[report_format.replace(' ', '_').upper()]
+            return cls[report_format.replace(" ", "_").upper()]
         except KeyError:
             raise InvalidArgument(
-                argument='report_format',
+                argument="report_format",
                 function=cls.from_string.__name__,
             ) from KeyError
 
@@ -82,7 +83,7 @@ class ReportFormatsMixin:
         if not report_format_id:
             raise RequiredArgument(
                 function=self.clone_report_format.__name__,
-                argument='report_format_id',
+                argument="report_format_id",
             )
 
         cmd = XmlCommand("create_report_format")
@@ -109,7 +110,7 @@ class ReportFormatsMixin:
         if not report_format_id:
             raise RequiredArgument(
                 function=self.delete_report_format.__name__,
-                argument='report_format_id',
+                argument="report_format_id",
             )
 
         cmd = XmlCommand("delete_report_format")
@@ -179,7 +180,7 @@ class ReportFormatsMixin:
         if not report_format_id:
             raise RequiredArgument(
                 function=self.get_report_format.__name__,
-                argument='report_format_id',
+                argument="report_format_id",
             )
 
         if isinstance(report_format_id, ReportFormatType):
@@ -204,7 +205,7 @@ class ReportFormatsMixin:
         if not report_format:
             raise RequiredArgument(
                 function=self.import_report_format.__name__,
-                argument='report_format',
+                argument="report_format",
             )
 
         cmd = XmlCommand("create_report_format")
@@ -214,7 +215,7 @@ class ReportFormatsMixin:
         except XMLSyntaxError as e:
             raise InvalidArgument(
                 function=self.import_report_format.__name__,
-                argument='report_format',
+                argument="report_format",
             ) from e
 
         return self._send_xml_command(cmd)
@@ -246,7 +247,7 @@ class ReportFormatsMixin:
         if not report_format_id:
             raise RequiredArgument(
                 function=self.modify_report_format.__name__,
-                argument='report_format_id ',
+                argument="report_format_id ",
             )
 
         cmd = XmlCommand("modify_report_format")
@@ -295,7 +296,7 @@ class ReportFormatsMixin:
         if not report_format_id:
             raise RequiredArgument(
                 function=self.verify_report_format.__name__,
-                argument='report_format_id',
+                argument="report_format_id",
             )
 
         cmd = XmlCommand("verify_report_format")
