@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2021 Greenbone Networks GmbH
+# Copyright (C) 2021-2022 Greenbone Networks GmbH
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -47,7 +47,7 @@ class InfoType(Enum):
             return cls[info_type.upper()]
         except KeyError:
             raise InvalidArgument(
-                argument='info_type', function=cls.from_string.__name__
+                argument="info_type", function=cls.from_string.__name__
             ) from None
 
 
@@ -142,7 +142,7 @@ class SecInfoMixin:
 
         if not nvt_oid:
             raise RequiredArgument(
-                function=self.get_scan_config_nvt.__name__, argument='nvt_oid'
+                function=self.get_scan_config_nvt.__name__, argument="nvt_oid"
             )
 
         cmd.set_attribute("nvt_oid", nvt_oid)
@@ -340,7 +340,7 @@ class SecInfoMixin:
 
         Arguments:
             info_type: Type must be either CERT_BUND_ADV, CPE, CVE,
-                DFN_CERT_ADV, OVALDEF, NVT or ALLINFO
+                DFN_CERT_ADV, OVALDEF or NVT
             filter_string: Filter term to use for the query
             filter_id: UUID of an existing filter to use for the query
             name: Name or identifier of the requested information
@@ -352,13 +352,13 @@ class SecInfoMixin:
         """
         if not info_type:
             raise RequiredArgument(
-                function=self.get_info_list.__name__, argument='info_type'
+                function=self.get_info_list.__name__, argument="info_type"
             )
 
         if not isinstance(info_type, InfoType):
             raise InvalidArgumentType(
                 function=self.get_info_list.__name__,
-                argument='info_type',
+                argument="info_type",
                 arg_type=InfoType.__name__,
             )
 
@@ -461,19 +461,19 @@ class SecInfoMixin:
         """
         if not info_type:
             raise RequiredArgument(
-                function=self.get_info.__name__, argument='info_type'
+                function=self.get_info.__name__, argument="info_type"
             )
 
         if not isinstance(info_type, InfoType):
             raise InvalidArgumentType(
                 function=self.get_info.__name__,
-                argument='info_type',
+                argument="info_type",
                 arg_type=InfoType.__name__,
             )
 
         if not info_id:
             raise RequiredArgument(
-                function=self.get_info.__name__, argument='info_id'
+                function=self.get_info.__name__, argument="info_id"
             )
 
         cmd = XmlCommand("get_info")
@@ -528,7 +528,7 @@ class SecInfoMixin:
 
         if not name:
             raise RequiredArgument(
-                function=self.get_nvt_preference.__name__, argument='name'
+                function=self.get_nvt_preference.__name__, argument="name"
             )
 
         cmd.set_attribute("preference", name)
