@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2018-2021 Greenbone Networks GmbH
+# Copyright (C) 2018-2022 Greenbone Networks GmbH
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -23,7 +23,7 @@ Module for communication to a daemon speaking `Open Scanner Protocol version 1`_
 """
 import logging
 
-from gvm.errors import RequiredArgument, InvalidArgument
+from gvm.errors import InvalidArgument, RequiredArgument
 from gvm.xml import XmlCommand
 
 from .base import GvmProtocol
@@ -263,7 +263,7 @@ class Osp(GvmProtocol):
                 cmd.set_attribute("ports", ports)
         else:
             raise RequiredArgument(
-                function=self.start_scan.__name__, argument='targets'
+                function=self.start_scan.__name__, argument="targets"
             )
 
         if vt_selection:
@@ -285,7 +285,7 @@ class Osp(GvmProtocol):
         """
         if not scan_id:
             raise RequiredArgument(
-                function=self.stop_scan.__name__, argument='scan_id'
+                function=self.stop_scan.__name__, argument="scan_id"
             )
 
         cmd = XmlCommand("stop_scan")
