@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2018-2021 Greenbone Networks GmbH
+# Copyright (C) 2018-2022 Greenbone Networks GmbH
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -19,10 +19,11 @@
 # pylint: disable=arguments-differ, redefined-builtin
 
 import base64
-import warnings
 import logging
-
+import re
+import warnings
 from typing import Any, List
+
 from lxml import etree
 
 from gvm.xml import create_parser
@@ -100,3 +101,12 @@ def add_filter(cmd, filter_string, filter_id):
 
 def is_list_like(value: Any) -> bool:
     return isinstance(value, (list, tuple))
+
+
+def check_port(value: str) -> bool:
+    pattern = re.compile(
+        r"^(cpe:[^\s]+|(general|[1-9][0-9]{0,4})/[0-9A-Za-z]+)$"
+    )
+    if pattern.fullmatch(value):
+        return True
+    return False
