@@ -21,15 +21,15 @@ from gvm.errors import RequiredArgument
 
 class GmpCloneAlertTestMixin:
     def test_clone(self):
-        self.gmp.clone_alert('a1')
+        self.gmp.clone_alert("a1")
 
         self.connection.send.has_been_called_with(
-            '<create_alert>' '<copy>a1</copy>' '</create_alert>'
+            "<create_alert>" "<copy>a1</copy>" "</create_alert>"
         )
 
     def test_missing_id(self):
         with self.assertRaises(RequiredArgument):
-            self.gmp.clone_alert('')
+            self.gmp.clone_alert("")
 
         with self.assertRaises(RequiredArgument):
             self.gmp.clone_alert(None)
