@@ -16,8 +16,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from gvm.errors import RequiredArgument, InvalidArgument, InvalidArgumentType
-
+from gvm.errors import InvalidArgument, InvalidArgumentType, RequiredArgument
 from gvm.protocols.gmpv208 import AlertCondition, AlertEvent, AlertMethod
 
 
@@ -25,7 +24,7 @@ class GmpCreateAlertTestMixin:
     def test_missing_name(self):
         with self.assertRaises(RequiredArgument):
             self.gmp.create_alert(
-                name='',
+                name="",
                 condition=AlertCondition.ALWAYS,
                 event=AlertEvent.TASK_RUN_STATUS_CHANGED,
                 method=AlertMethod.EMAIL,
@@ -42,41 +41,41 @@ class GmpCreateAlertTestMixin:
     def test_missing_condition(self):
         with self.assertRaises(RequiredArgument):
             self.gmp.create_alert(
-                name='foo', condition='', event='bar', method='lorem'
+                name="foo", condition="", event="bar", method="lorem"
             )
 
         with self.assertRaises(RequiredArgument):
             self.gmp.create_alert(
-                name='foo', condition=None, event='bar', method='lorem'
+                name="foo", condition=None, event="bar", method="lorem"
             )
 
     def test_missing_event(self):
         with self.assertRaises(RequiredArgument):
             self.gmp.create_alert(
-                name='foo', condition='bar', event='', method='lorem'
+                name="foo", condition="bar", event="", method="lorem"
             )
 
         with self.assertRaises(RequiredArgument):
             self.gmp.create_alert(
-                name='foo', condition='bar', event=None, method='lorem'
+                name="foo", condition="bar", event=None, method="lorem"
             )
 
     def test_missing_method(self):
         with self.assertRaises(RequiredArgument):
             self.gmp.create_alert(
-                name='foo', condition='bar', event='lorem', method=''
+                name="foo", condition="bar", event="lorem", method=""
             )
 
         with self.assertRaises(RequiredArgument):
             self.gmp.create_alert(
-                name='foo', condition='bar', event='lorem', method=None
+                name="foo", condition="bar", event="lorem", method=None
             )
 
     def test_invalid_condition(self):
         with self.assertRaises(InvalidArgumentType):
             self.gmp.create_alert(
-                name='foo',
-                condition='bar',
+                name="foo",
+                condition="bar",
                 event=AlertEvent.TASK_RUN_STATUS_CHANGED,
                 method=AlertMethod.EMAIL,
             )
@@ -84,25 +83,25 @@ class GmpCreateAlertTestMixin:
     def test_invalid_event(self):
         with self.assertRaises(InvalidArgumentType):
             self.gmp.create_alert(
-                name='foo',
+                name="foo",
                 condition=AlertCondition.ALWAYS,
-                event='lorem',
+                event="lorem",
                 method=AlertMethod.EMAIL,
             )
 
     def test_invalid_method(self):
         with self.assertRaises(InvalidArgumentType):
             self.gmp.create_alert(
-                name='foo',
+                name="foo",
                 condition=AlertCondition.ALWAYS,
                 event=AlertEvent.TASK_RUN_STATUS_CHANGED,
-                method='ipsum',
+                method="ipsum",
             )
 
     def test_invalid_condition_for_secinfo(self):
         with self.assertRaises(InvalidArgument):
             self.gmp.create_alert(
-                name='foo',
+                name="foo",
                 condition=AlertCondition.SEVERITY_AT_LEAST,
                 event=AlertEvent.UPDATED_SECINFO_ARRIVED,
                 method=AlertMethod.EMAIL,
@@ -111,7 +110,7 @@ class GmpCreateAlertTestMixin:
     def test_invalid_method_for_secinfo(self):
         with self.assertRaises(InvalidArgument):
             self.gmp.create_alert(
-                name='foo',
+                name="foo",
                 condition=AlertCondition.ALWAYS,
                 event=AlertEvent.UPDATED_SECINFO_ARRIVED,
                 method=AlertMethod.HTTP_GET,
@@ -119,7 +118,7 @@ class GmpCreateAlertTestMixin:
 
         with self.assertRaises(InvalidArgument):
             self.gmp.create_alert(
-                name='foo',
+                name="foo",
                 condition=AlertCondition.ALWAYS,
                 event=AlertEvent.UPDATED_SECINFO_ARRIVED,
                 method=AlertMethod.ALEMBA_VFIRE,
@@ -127,7 +126,7 @@ class GmpCreateAlertTestMixin:
 
         with self.assertRaises(InvalidArgument):
             self.gmp.create_alert(
-                name='foo',
+                name="foo",
                 condition=AlertCondition.ALWAYS,
                 event=AlertEvent.UPDATED_SECINFO_ARRIVED,
                 method=AlertMethod.SOURCEFIRE_CONNECTOR,
@@ -135,7 +134,7 @@ class GmpCreateAlertTestMixin:
 
         with self.assertRaises(InvalidArgument):
             self.gmp.create_alert(
-                name='foo',
+                name="foo",
                 condition=AlertCondition.ALWAYS,
                 event=AlertEvent.UPDATED_SECINFO_ARRIVED,
                 method=AlertMethod.START_TASK,
@@ -143,7 +142,7 @@ class GmpCreateAlertTestMixin:
 
         with self.assertRaises(InvalidArgument):
             self.gmp.create_alert(
-                name='foo',
+                name="foo",
                 condition=AlertCondition.ALWAYS,
                 event=AlertEvent.UPDATED_SECINFO_ARRIVED,
                 method=AlertMethod.TIPPINGPOINT_SMS,
@@ -151,7 +150,7 @@ class GmpCreateAlertTestMixin:
 
         with self.assertRaises(InvalidArgument):
             self.gmp.create_alert(
-                name='foo',
+                name="foo",
                 condition=AlertCondition.ALWAYS,
                 event=AlertEvent.UPDATED_SECINFO_ARRIVED,
                 method=AlertMethod.VERINICE_CONNECTOR,
@@ -159,7 +158,7 @@ class GmpCreateAlertTestMixin:
 
         with self.assertRaises(InvalidArgument):
             self.gmp.create_alert(
-                name='foo',
+                name="foo",
                 condition=AlertCondition.ALWAYS,
                 event=AlertEvent.NEW_SECINFO_ARRIVED,
                 method=AlertMethod.HTTP_GET,
@@ -167,7 +166,7 @@ class GmpCreateAlertTestMixin:
 
         with self.assertRaises(InvalidArgument):
             self.gmp.create_alert(
-                name='foo',
+                name="foo",
                 condition=AlertCondition.ALWAYS,
                 event=AlertEvent.NEW_SECINFO_ARRIVED,
                 method=AlertMethod.ALEMBA_VFIRE,
@@ -175,7 +174,7 @@ class GmpCreateAlertTestMixin:
 
         with self.assertRaises(InvalidArgument):
             self.gmp.create_alert(
-                name='foo',
+                name="foo",
                 condition=AlertCondition.ALWAYS,
                 event=AlertEvent.NEW_SECINFO_ARRIVED,
                 method=AlertMethod.SOURCEFIRE_CONNECTOR,
@@ -183,7 +182,7 @@ class GmpCreateAlertTestMixin:
 
         with self.assertRaises(InvalidArgument):
             self.gmp.create_alert(
-                name='foo',
+                name="foo",
                 condition=AlertCondition.ALWAYS,
                 event=AlertEvent.NEW_SECINFO_ARRIVED,
                 method=AlertMethod.START_TASK,
@@ -191,7 +190,7 @@ class GmpCreateAlertTestMixin:
 
         with self.assertRaises(InvalidArgument):
             self.gmp.create_alert(
-                name='foo',
+                name="foo",
                 condition=AlertCondition.ALWAYS,
                 event=AlertEvent.NEW_SECINFO_ARRIVED,
                 method=AlertMethod.TIPPINGPOINT_SMS,
@@ -199,7 +198,7 @@ class GmpCreateAlertTestMixin:
 
         with self.assertRaises(InvalidArgument):
             self.gmp.create_alert(
-                name='foo',
+                name="foo",
                 condition=AlertCondition.ALWAYS,
                 event=AlertEvent.NEW_SECINFO_ARRIVED,
                 method=AlertMethod.VERINICE_CONNECTOR,
@@ -208,7 +207,7 @@ class GmpCreateAlertTestMixin:
     def test_missing_method_for_ticket_received(self):
         with self.assertRaises(RequiredArgument):
             self.gmp.create_alert(
-                name='foo',
+                name="foo",
                 condition=AlertCondition.ALWAYS,
                 event=AlertEvent.TICKET_RECEIVED,
                 method=None,
@@ -217,7 +216,7 @@ class GmpCreateAlertTestMixin:
     def test_missing_condition_for_ticket_received(self):
         with self.assertRaises(RequiredArgument):
             self.gmp.create_alert(
-                name='foo',
+                name="foo",
                 condition=None,
                 event=AlertEvent.TICKET_RECEIVED,
                 method=AlertMethod.EMAIL,
@@ -226,7 +225,7 @@ class GmpCreateAlertTestMixin:
     def test_invalid_method_for_ticket_received(self):
         with self.assertRaises(InvalidArgument):
             self.gmp.create_alert(
-                name='foo',
+                name="foo",
                 condition=AlertCondition.ALWAYS,
                 event=AlertEvent.TICKET_RECEIVED,
                 method=AlertMethod.HTTP_GET,
@@ -234,7 +233,7 @@ class GmpCreateAlertTestMixin:
 
         with self.assertRaises(InvalidArgument):
             self.gmp.create_alert(
-                name='foo',
+                name="foo",
                 condition=AlertCondition.ALWAYS,
                 event=AlertEvent.TICKET_RECEIVED,
                 method=AlertMethod.SCP,
@@ -242,7 +241,7 @@ class GmpCreateAlertTestMixin:
 
         with self.assertRaises(InvalidArgument):
             self.gmp.create_alert(
-                name='foo',
+                name="foo",
                 condition=AlertCondition.ALWAYS,
                 event=AlertEvent.TICKET_RECEIVED,
                 method=AlertMethod.SEND,
@@ -250,7 +249,7 @@ class GmpCreateAlertTestMixin:
 
         with self.assertRaises(InvalidArgument):
             self.gmp.create_alert(
-                name='foo',
+                name="foo",
                 condition=AlertCondition.ALWAYS,
                 event=AlertEvent.TICKET_RECEIVED,
                 method=AlertMethod.SMB,
@@ -258,7 +257,7 @@ class GmpCreateAlertTestMixin:
 
         with self.assertRaises(InvalidArgument):
             self.gmp.create_alert(
-                name='foo',
+                name="foo",
                 condition=AlertCondition.ALWAYS,
                 event=AlertEvent.TICKET_RECEIVED,
                 method=AlertMethod.SNMP,
@@ -266,7 +265,7 @@ class GmpCreateAlertTestMixin:
 
         with self.assertRaises(InvalidArgument):
             self.gmp.create_alert(
-                name='foo',
+                name="foo",
                 condition=AlertCondition.ALWAYS,
                 event=AlertEvent.TICKET_RECEIVED,
                 method=AlertMethod.ALEMBA_VFIRE,
@@ -274,7 +273,7 @@ class GmpCreateAlertTestMixin:
 
         with self.assertRaises(InvalidArgument):
             self.gmp.create_alert(
-                name='foo',
+                name="foo",
                 condition=AlertCondition.ALWAYS,
                 event=AlertEvent.TICKET_RECEIVED,
                 method=AlertMethod.VERINICE_CONNECTOR,
@@ -282,7 +281,7 @@ class GmpCreateAlertTestMixin:
 
         with self.assertRaises(InvalidArgument):
             self.gmp.create_alert(
-                name='foo',
+                name="foo",
                 condition=AlertCondition.ALWAYS,
                 event=AlertEvent.TICKET_RECEIVED,
                 method=AlertMethod.TIPPINGPOINT_SMS,
@@ -290,7 +289,7 @@ class GmpCreateAlertTestMixin:
 
         with self.assertRaises(InvalidArgument):
             self.gmp.create_alert(
-                name='foo',
+                name="foo",
                 condition=AlertCondition.ALWAYS,
                 event=AlertEvent.TICKET_RECEIVED,
                 method=AlertMethod.SOURCEFIRE_CONNECTOR,
@@ -299,7 +298,7 @@ class GmpCreateAlertTestMixin:
     def test_invalid_condition_for_task_run_status_changed(self):
         with self.assertRaises(InvalidArgument):
             self.gmp.create_alert(
-                name='foo',
+                name="foo",
                 condition=AlertCondition.ERROR,
                 event=AlertEvent.TASK_RUN_STATUS_CHANGED,
                 method=AlertMethod.EMAIL,
@@ -308,7 +307,7 @@ class GmpCreateAlertTestMixin:
     def test_invalid_condition_for_ticket_received(self):
         with self.assertRaises(InvalidArgument):
             self.gmp.create_alert(
-                name='foo',
+                name="foo",
                 condition=AlertCondition.FILTER_COUNT_AT_LEAST,
                 event=AlertEvent.TICKET_RECEIVED,
                 method=AlertMethod.EMAIL,
@@ -316,111 +315,111 @@ class GmpCreateAlertTestMixin:
 
     def test_create_alert(self):
         self.gmp.create_alert(
-            name='foo',
+            name="foo",
             condition=AlertCondition.ALWAYS,
             event=AlertEvent.TASK_RUN_STATUS_CHANGED,
             method=AlertMethod.EMAIL,
         )
 
         self.connection.send.has_been_called_with(
-            '<create_alert>'
-            '<name>foo</name>'
-            '<condition>Always</condition>'
-            '<event>Task run status changed</event>'
-            '<method>Email</method>'
-            '</create_alert>'
+            "<create_alert>"
+            "<name>foo</name>"
+            "<condition>Always</condition>"
+            "<event>Task run status changed</event>"
+            "<method>Email</method>"
+            "</create_alert>"
         )
 
     def test_create_alert_with_filter_id(self):
         self.gmp.create_alert(
-            name='foo',
+            name="foo",
             condition=AlertCondition.ALWAYS,
             event=AlertEvent.TASK_RUN_STATUS_CHANGED,
             method=AlertMethod.EMAIL,
-            filter_id='f1',
+            filter_id="f1",
         )
 
         self.connection.send.has_been_called_with(
-            '<create_alert>'
-            '<name>foo</name>'
-            '<condition>Always</condition>'
-            '<event>Task run status changed</event>'
-            '<method>Email</method>'
+            "<create_alert>"
+            "<name>foo</name>"
+            "<condition>Always</condition>"
+            "<event>Task run status changed</event>"
+            "<method>Email</method>"
             '<filter id="f1"/>'
-            '</create_alert>'
+            "</create_alert>"
         )
 
     def test_create_alert_with_comment(self):
         self.gmp.create_alert(
-            name='foo',
+            name="foo",
             condition=AlertCondition.ALWAYS,
             event=AlertEvent.TASK_RUN_STATUS_CHANGED,
             method=AlertMethod.EMAIL,
-            comment='hello',
+            comment="hello",
         )
 
         self.connection.send.has_been_called_with(
-            '<create_alert>'
-            '<name>foo</name>'
-            '<condition>Always</condition>'
-            '<event>Task run status changed</event>'
-            '<method>Email</method>'
-            '<comment>hello</comment>'
-            '</create_alert>'
+            "<create_alert>"
+            "<name>foo</name>"
+            "<condition>Always</condition>"
+            "<event>Task run status changed</event>"
+            "<method>Email</method>"
+            "<comment>hello</comment>"
+            "</create_alert>"
         )
 
     def test_create_alert_with_condition_data(self):
         self.gmp.create_alert(
-            name='foo',
+            name="foo",
             condition=AlertCondition.ALWAYS,
             event=AlertEvent.TASK_RUN_STATUS_CHANGED,
             method=AlertMethod.EMAIL,
-            condition_data={'foo': 'bar'},
+            condition_data={"foo": "bar"},
         )
 
         self.connection.send.has_been_called_with(
-            '<create_alert>'
-            '<name>foo</name>'
-            '<condition>Always<data>bar<name>foo</name></data></condition>'
-            '<event>Task run status changed</event>'
-            '<method>Email</method>'
-            '</create_alert>'
+            "<create_alert>"
+            "<name>foo</name>"
+            "<condition>Always<data>bar<name>foo</name></data></condition>"
+            "<event>Task run status changed</event>"
+            "<method>Email</method>"
+            "</create_alert>"
         )
 
     def test_create_alert_with_event_data(self):
         self.gmp.create_alert(
-            name='foo',
+            name="foo",
             condition=AlertCondition.ALWAYS,
             event=AlertEvent.TASK_RUN_STATUS_CHANGED,
             method=AlertMethod.EMAIL,
-            event_data={'foo': 'bar'},
+            event_data={"foo": "bar"},
         )
 
         self.connection.send.has_been_called_with(
-            '<create_alert>'
-            '<name>foo</name>'
-            '<condition>Always</condition>'
-            '<event>Task run status changed'
-            '<data>bar<name>foo</name></data>'
-            '</event>'
-            '<method>Email</method>'
-            '</create_alert>'
+            "<create_alert>"
+            "<name>foo</name>"
+            "<condition>Always</condition>"
+            "<event>Task run status changed"
+            "<data>bar<name>foo</name></data>"
+            "</event>"
+            "<method>Email</method>"
+            "</create_alert>"
         )
 
     def test_create_alert_with_method_data(self):
         self.gmp.create_alert(
-            name='foo',
+            name="foo",
             condition=AlertCondition.ALWAYS,
             event=AlertEvent.TASK_RUN_STATUS_CHANGED,
             method=AlertMethod.EMAIL,
-            method_data={'foo': 'bar'},
+            method_data={"foo": "bar"},
         )
 
         self.connection.send.has_been_called_with(
-            '<create_alert>'
-            '<name>foo</name>'
-            '<condition>Always</condition>'
-            '<event>Task run status changed</event>'
-            '<method>Email<data>bar<name>foo</name></data></method>'
-            '</create_alert>'
+            "<create_alert>"
+            "<name>foo</name>"
+            "<condition>Always</condition>"
+            "<event>Task run status changed</event>"
+            "<method>Email<data>bar<name>foo</name></data></method>"
+            "</create_alert>"
         )
