@@ -21,14 +21,14 @@ from gvm.errors import RequiredArgument
 
 class GmpDeleteAlertTestMixin:
     def test_delete(self):
-        self.gmp.delete_alert('a1')
+        self.gmp.delete_alert("a1")
 
         self.connection.send.has_been_called_with(
             '<delete_alert alert_id="a1" ultimate="0"/>'
         )
 
     def test_delete_ultimate(self):
-        self.gmp.delete_alert('a1', ultimate=True)
+        self.gmp.delete_alert("a1", ultimate=True)
 
         self.connection.send.has_been_called_with(
             '<delete_alert alert_id="a1" ultimate="1"/>'
@@ -39,4 +39,4 @@ class GmpDeleteAlertTestMixin:
             self.gmp.delete_alert(None)
 
         with self.assertRaises(RequiredArgument):
-            self.gmp.delete_alert('')
+            self.gmp.delete_alert("")
