@@ -21,11 +21,11 @@ from gvm.errors import RequiredArgument
 
 class GmpGetAlertTestMixin:
     def test_get_alert(self):
-        self.gmp.get_alert('a1')
+        self.gmp.get_alert("a1")
 
         self.connection.send.has_been_called_with('<get_alerts alert_id="a1"/>')
 
-        self.gmp.get_alert(alert_id='a1')
+        self.gmp.get_alert(alert_id="a1")
 
         self.connection.send.has_been_called_with('<get_alerts alert_id="a1"/>')
 
@@ -34,16 +34,16 @@ class GmpGetAlertTestMixin:
             self.gmp.get_alert(alert_id=None)
 
         with self.assertRaises(RequiredArgument):
-            self.gmp.get_alert(alert_id='')
+            self.gmp.get_alert(alert_id="")
 
     def test_get_alert_with_tasks(self):
-        self.gmp.get_alert(alert_id='a1', tasks=True)
+        self.gmp.get_alert(alert_id="a1", tasks=True)
 
         self.connection.send.has_been_called_with(
             '<get_alerts alert_id="a1" tasks="1"/>'
         )
 
-        self.gmp.get_alert(alert_id='a1', tasks=False)
+        self.gmp.get_alert(alert_id="a1", tasks=False)
 
         self.connection.send.has_been_called_with(
             '<get_alerts alert_id="a1" tasks="0"/>'
