@@ -21,14 +21,14 @@ from gvm.errors import GvmError
 
 class GmpDeleteAuditTestMixin:
     def test_delete(self):
-        self.gmp.delete_audit('a1')
+        self.gmp.delete_audit("a1")
 
         self.connection.send.has_been_called_with(
             '<delete_task task_id="a1" ultimate="0"/>'
         )
 
     def test_delete_ultimate(self):
-        self.gmp.delete_audit('a1', ultimate=True)
+        self.gmp.delete_audit("a1", ultimate=True)
 
         self.connection.send.has_been_called_with(
             '<delete_task task_id="a1" ultimate="1"/>'
@@ -39,4 +39,4 @@ class GmpDeleteAuditTestMixin:
             self.gmp.delete_audit(None)
 
         with self.assertRaises(GvmError):
-            self.gmp.delete_audit('')
+            self.gmp.delete_audit("")
