@@ -17,13 +17,12 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from gvm.errors import InvalidArgumentType, RequiredArgument
-
 from gvm.protocols.gmpv208 import CredentialFormat
 
 
 class GmpGetCredentialTestMixin:
     def test_get_credential(self):
-        self.gmp.get_credential('id')
+        self.gmp.get_credential("id")
 
         self.connection.send.has_been_called_with(
             '<get_credentials credential_id="id"/>'
@@ -38,34 +37,34 @@ class GmpGetCredentialTestMixin:
             self.gmp.get_credential(credential_id=None)
 
         with self.assertRaises(RequiredArgument):
-            self.gmp.get_credential('')
+            self.gmp.get_credential("")
 
     def test_get_credential_with_credential_format(self):
-        self.gmp.get_credential('id', credential_format=CredentialFormat.KEY)
+        self.gmp.get_credential("id", credential_format=CredentialFormat.KEY)
 
         self.connection.send.has_been_called_with(
             '<get_credentials credential_id="id" format="key"/>'
         )
 
-        self.gmp.get_credential('id', credential_format=CredentialFormat.RPM)
+        self.gmp.get_credential("id", credential_format=CredentialFormat.RPM)
 
         self.connection.send.has_been_called_with(
             '<get_credentials credential_id="id" format="rpm"/>'
         )
 
-        self.gmp.get_credential('id', credential_format=CredentialFormat.DEB)
+        self.gmp.get_credential("id", credential_format=CredentialFormat.DEB)
 
         self.connection.send.has_been_called_with(
             '<get_credentials credential_id="id" format="deb"/>'
         )
 
-        self.gmp.get_credential('id', credential_format=CredentialFormat.EXE)
+        self.gmp.get_credential("id", credential_format=CredentialFormat.EXE)
 
         self.connection.send.has_been_called_with(
             '<get_credentials credential_id="id" format="exe"/>'
         )
 
-        self.gmp.get_credential('id', credential_format=CredentialFormat.PEM)
+        self.gmp.get_credential("id", credential_format=CredentialFormat.PEM)
 
         self.connection.send.has_been_called_with(
             '<get_credentials credential_id="id" format="pem"/>'
@@ -73,29 +72,29 @@ class GmpGetCredentialTestMixin:
 
     def test_get_credential_with_invalid_credential_format(self):
         with self.assertRaises(InvalidArgumentType):
-            self.gmp.get_credential('id', credential_format='foo')
+            self.gmp.get_credential("id", credential_format="foo")
 
     def test_get_credential_with_scanners(self):
-        self.gmp.get_credential('id', scanners=True)
+        self.gmp.get_credential("id", scanners=True)
 
         self.connection.send.has_been_called_with(
             '<get_credentials credential_id="id" scanners="1"/>'
         )
 
-        self.gmp.get_credential('id', scanners=False)
+        self.gmp.get_credential("id", scanners=False)
 
         self.connection.send.has_been_called_with(
             '<get_credentials credential_id="id" scanners="0"/>'
         )
 
     def test_get_credential_with_targets(self):
-        self.gmp.get_credential('id', targets=True)
+        self.gmp.get_credential("id", targets=True)
 
         self.connection.send.has_been_called_with(
             '<get_credentials credential_id="id" targets="1"/>'
         )
 
-        self.gmp.get_credential('id', targets=False)
+        self.gmp.get_credential("id", targets=False)
 
         self.connection.send.has_been_called_with(
             '<get_credentials credential_id="id" targets="0"/>'
