@@ -21,14 +21,14 @@ from gvm.errors import GvmError
 
 class GmpDeleteFilterTestMixin:
     def test_delete(self):
-        self.gmp.delete_filter('a1')
+        self.gmp.delete_filter("a1")
 
         self.connection.send.has_been_called_with(
             '<delete_filter filter_id="a1" ultimate="0"/>'
         )
 
     def test_delete_ultimate(self):
-        self.gmp.delete_filter('a1', ultimate=True)
+        self.gmp.delete_filter("a1", ultimate=True)
 
         self.connection.send.has_been_called_with(
             '<delete_filter filter_id="a1" ultimate="1"/>'
@@ -39,4 +39,4 @@ class GmpDeleteFilterTestMixin:
             self.gmp.delete_filter(None)
 
         with self.assertRaises(GvmError):
-            self.gmp.delete_filter('')
+            self.gmp.delete_filter("")
