@@ -21,15 +21,15 @@ from gvm.errors import RequiredArgument
 
 class GmpCloneGroupTestMixin:
     def test_clone(self):
-        self.gmp.clone_group('a1')
+        self.gmp.clone_group("a1")
 
         self.connection.send.has_been_called_with(
-            '<create_group>' '<copy>a1</copy>' '</create_group>'
+            "<create_group>" "<copy>a1</copy>" "</create_group>"
         )
 
     def test_missing_id(self):
         with self.assertRaises(RequiredArgument):
-            self.gmp.clone_group('')
+            self.gmp.clone_group("")
 
         with self.assertRaises(RequiredArgument):
             self.gmp.clone_group(None)
