@@ -21,7 +21,7 @@ from gvm.errors import RequiredArgument
 
 class GmpModifyGroupTestMixin:
     def test_modify_group(self):
-        self.gmp.modify_group(group_id='f1')
+        self.gmp.modify_group(group_id="f1")
 
         self.connection.send.has_been_called_with(
             '<modify_group group_id="f1"/>'
@@ -32,40 +32,40 @@ class GmpModifyGroupTestMixin:
             self.gmp.modify_group(group_id=None)
 
         with self.assertRaises(RequiredArgument):
-            self.gmp.modify_group(group_id='')
+            self.gmp.modify_group(group_id="")
 
         with self.assertRaises(RequiredArgument):
-            self.gmp.modify_group('')
+            self.gmp.modify_group("")
 
     def test_modify_group_with_comment(self):
-        self.gmp.modify_group(group_id='f1', comment='foo')
+        self.gmp.modify_group(group_id="f1", comment="foo")
 
         self.connection.send.has_been_called_with(
             '<modify_group group_id="f1">'
-            '<comment>foo</comment>'
-            '</modify_group>'
+            "<comment>foo</comment>"
+            "</modify_group>"
         )
 
     def test_modify_group_with_name(self):
-        self.gmp.modify_group(group_id='f1', name='foo')
+        self.gmp.modify_group(group_id="f1", name="foo")
 
         self.connection.send.has_been_called_with(
-            '<modify_group group_id="f1">' '<name>foo</name>' '</modify_group>'
+            '<modify_group group_id="f1">' "<name>foo</name>" "</modify_group>"
         )
 
     def test_modify_group_with_users(self):
-        self.gmp.modify_group(group_id='f1', users=['foo'])
+        self.gmp.modify_group(group_id="f1", users=["foo"])
 
         self.connection.send.has_been_called_with(
             '<modify_group group_id="f1">'
-            '<users>foo</users>'
-            '</modify_group>'
+            "<users>foo</users>"
+            "</modify_group>"
         )
 
-        self.gmp.modify_group(group_id='f1', users=['foo', 'bar'])
+        self.gmp.modify_group(group_id="f1", users=["foo", "bar"])
 
         self.connection.send.has_been_called_with(
             '<modify_group group_id="f1">'
-            '<users>foo,bar</users>'
-            '</modify_group>'
+            "<users>foo,bar</users>"
+            "</modify_group>"
         )
