@@ -21,17 +21,17 @@ class GmpGetNotesTestMixin:
     def test_get_notes(self):
         self.gmp.get_notes()
 
-        self.connection.send.has_been_called_with('<get_notes/>')
+        self.connection.send.has_been_called_with("<get_notes/>")
 
     def test_get_notes_with_filter_string(self):
-        self.gmp.get_notes(filter_string='foo=bar')
+        self.gmp.get_notes(filter_string="foo=bar")
 
         self.connection.send.has_been_called_with(
             '<get_notes filter="foo=bar"/>'
         )
 
     def test_get_notes_with_filter_id(self):
-        self.gmp.get_notes(filter_id='f1')
+        self.gmp.get_notes(filter_id="f1")
 
         self.connection.send.has_been_called_with('<get_notes filt_id="f1"/>')
 
