@@ -21,14 +21,14 @@ from gvm.errors import GvmError
 
 class GmpDeleteOverrideTestMixin:
     def test_delete(self):
-        self.gmp.delete_override('a1')
+        self.gmp.delete_override("a1")
 
         self.connection.send.has_been_called_with(
             '<delete_override override_id="a1" ultimate="0"/>'
         )
 
     def test_delete_ultimate(self):
-        self.gmp.delete_override('a1', ultimate=True)
+        self.gmp.delete_override("a1", ultimate=True)
 
         self.connection.send.has_been_called_with(
             '<delete_override override_id="a1" ultimate="1"/>'
@@ -39,4 +39,4 @@ class GmpDeleteOverrideTestMixin:
             self.gmp.delete_override(None)
 
         with self.assertRaises(GvmError):
-            self.gmp.delete_override('')
+            self.gmp.delete_override("")
