@@ -21,13 +21,13 @@ from gvm.errors import RequiredArgument
 
 class GmpGetOverrideTestMixin:
     def test_get_override(self):
-        self.gmp.get_override('o1')
+        self.gmp.get_override("o1")
 
         self.connection.send.has_been_called_with(
             '<get_overrides override_id="o1" details="1"/>'
         )
 
-        self.gmp.get_override(override_id='o1')
+        self.gmp.get_override(override_id="o1")
 
         self.connection.send.has_been_called_with(
             '<get_overrides override_id="o1" details="1"/>'
@@ -38,4 +38,4 @@ class GmpGetOverrideTestMixin:
             self.gmp.get_override(override_id=None)
 
         with self.assertRaises(RequiredArgument):
-            self.gmp.get_override('')
+            self.gmp.get_override("")
