@@ -21,13 +21,13 @@ from gvm.errors import RequiredArgument
 
 class GmpGetPermissionTestMixin:
     def test_get_permission(self):
-        self.gmp.get_permission('p1')
+        self.gmp.get_permission("p1")
 
         self.connection.send.has_been_called_with(
             '<get_permissions permission_id="p1"/>'
         )
 
-        self.gmp.get_permission(permission_id='p1')
+        self.gmp.get_permission(permission_id="p1")
 
         self.connection.send.has_been_called_with(
             '<get_permissions permission_id="p1"/>'
@@ -38,4 +38,4 @@ class GmpGetPermissionTestMixin:
             self.gmp.get_permission(permission_id=None)
 
         with self.assertRaises(RequiredArgument):
-            self.gmp.get_permission('')
+            self.gmp.get_permission("")
