@@ -26,14 +26,14 @@ class GmpGetPoliciesTestMixin:
         )
 
     def test_get_policies_with_filter_string(self):
-        self.gmp.get_policies(filter_string='name=foo')
+        self.gmp.get_policies(filter_string="name=foo")
 
         self.connection.send.has_been_called_with(
             '<get_configs usage_type="policy" filter="name=foo"/>'
         )
 
     def test_get_policies_with_filter_id(self):
-        self.gmp.get_policies(filter_id='f1')
+        self.gmp.get_policies(filter_id="f1")
 
         self.connection.send.has_been_called_with(
             '<get_configs usage_type="policy" filt_id="f1"/>'
