@@ -21,7 +21,7 @@ from gvm.errors import RequiredArgument
 
 class GmpGetPortListTestMixin:
     def test_get_port_list(self):
-        self.gmp.get_port_list(port_list_id='port_list_id')
+        self.gmp.get_port_list(port_list_id="port_list_id")
 
         self.connection.send.has_been_called_with(
             '<get_port_lists port_list_id="port_list_id" details="1"/>'
@@ -32,7 +32,7 @@ class GmpGetPortListTestMixin:
             self.gmp.get_port_list(port_list_id=None)
 
         with self.assertRaises(RequiredArgument):
-            self.gmp.get_port_list(port_list_id='')
+            self.gmp.get_port_list(port_list_id="")
 
         with self.assertRaises(RequiredArgument):
-            self.gmp.get_port_list('')
+            self.gmp.get_port_list("")
