@@ -21,7 +21,7 @@ from gvm.errors import GvmError
 
 class GmpDeleteReportTestMixin:
     def test_delete(self):
-        self.gmp.delete_report('a1')
+        self.gmp.delete_report("a1")
 
         self.connection.send.has_been_called_with(
             '<delete_report report_id="a1"/>'
@@ -32,4 +32,4 @@ class GmpDeleteReportTestMixin:
             self.gmp.delete_report(None)
 
         with self.assertRaises(GvmError):
-            self.gmp.delete_report('')
+            self.gmp.delete_report("")
