@@ -21,17 +21,17 @@ class GmpGetRolesTestMixin:
     def test_get_roles(self):
         self.gmp.get_roles()
 
-        self.connection.send.has_been_called_with('<get_roles/>')
+        self.connection.send.has_been_called_with("<get_roles/>")
 
     def test_get_roles_with_filter_string(self):
-        self.gmp.get_roles(filter_string='foo=bar')
+        self.gmp.get_roles(filter_string="foo=bar")
 
         self.connection.send.has_been_called_with(
             '<get_roles filter="foo=bar"/>'
         )
 
     def test_get_roles_with_filter_id(self):
-        self.gmp.get_roles(filter_id='f1')
+        self.gmp.get_roles(filter_id="f1")
 
         self.connection.send.has_been_called_with('<get_roles filt_id="f1"/>')
 
