@@ -21,7 +21,7 @@ from gvm.errors import RequiredArgument
 
 class GmpModifyRoleTestMixin:
     def test_modify_role(self):
-        self.gmp.modify_role(role_id='r1')
+        self.gmp.modify_role(role_id="r1")
 
         self.connection.send.has_been_called_with('<modify_role role_id="r1"/>')
 
@@ -30,42 +30,42 @@ class GmpModifyRoleTestMixin:
             self.gmp.modify_role(role_id=None)
 
         with self.assertRaises(RequiredArgument):
-            self.gmp.modify_role(role_id='')
+            self.gmp.modify_role(role_id="")
 
         with self.assertRaises(RequiredArgument):
-            self.gmp.modify_role('')
+            self.gmp.modify_role("")
 
     def test_modify_role_with_comment(self):
-        self.gmp.modify_role(role_id='r1', comment='foo')
+        self.gmp.modify_role(role_id="r1", comment="foo")
 
         self.connection.send.has_been_called_with(
             '<modify_role role_id="r1">'
-            '<comment>foo</comment>'
-            '</modify_role>'
+            "<comment>foo</comment>"
+            "</modify_role>"
         )
 
     def test_modify_role_with_name(self):
-        self.gmp.modify_role(role_id='r1', name='foo')
+        self.gmp.modify_role(role_id="r1", name="foo")
 
         self.connection.send.has_been_called_with(
-            '<modify_role role_id="r1">' '<name>foo</name>' '</modify_role>'
+            '<modify_role role_id="r1">' "<name>foo</name>" "</modify_role>"
         )
 
     def test_modify_role_with_users(self):
-        self.gmp.modify_role(role_id='r1', users=[])
+        self.gmp.modify_role(role_id="r1", users=[])
 
         self.connection.send.has_been_called_with('<modify_role role_id="r1"/>')
 
-        self.gmp.modify_role(role_id='r1', users=['foo'])
+        self.gmp.modify_role(role_id="r1", users=["foo"])
 
         self.connection.send.has_been_called_with(
-            '<modify_role role_id="r1">' '<users>foo</users>' '</modify_role>'
+            '<modify_role role_id="r1">' "<users>foo</users>" "</modify_role>"
         )
 
-        self.gmp.modify_role(role_id='r1', users=['foo', 'bar'])
+        self.gmp.modify_role(role_id="r1", users=["foo", "bar"])
 
         self.connection.send.has_been_called_with(
             '<modify_role role_id="r1">'
-            '<users>foo,bar</users>'
-            '</modify_role>'
+            "<users>foo,bar</users>"
+            "</modify_role>"
         )
