@@ -17,26 +17,26 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 import warnings
 
-from gvm.errors import RequiredArgument, InvalidArgument
+from gvm.errors import InvalidArgument, RequiredArgument
 
 
 class GmpModifyScanConfigTestMixin:
     def test_modify_scan_config_invalid_selection(self):
         with self.assertRaises(InvalidArgument):
-            self.gmp.modify_scan_config(config_id='c1', selection='foo')
+            self.gmp.modify_scan_config(config_id="c1", selection="foo")
 
         with self.assertRaises(InvalidArgument):
-            self.gmp.modify_scan_config(config_id='c1', selection='')
+            self.gmp.modify_scan_config(config_id="c1", selection="")
 
     def test_modify_scan_config_missing_config_id(self):
         with self.assertRaises(RequiredArgument):
-            self.gmp.modify_scan_config(config_id=None, selection='nvt_pref')
+            self.gmp.modify_scan_config(config_id=None, selection="nvt_pref")
 
         with self.assertRaises(RequiredArgument):
-            self.gmp.modify_scan_config(config_id='', selection='nvt_pref')
+            self.gmp.modify_scan_config(config_id="", selection="nvt_pref")
 
         with self.assertRaises(RequiredArgument):
-            self.gmp.modify_scan_config('', selection='nvt_pref')
+            self.gmp.modify_scan_config("", selection="nvt_pref")
 
     def test_modify_scan_config_set_comment(self):
         # pylint: disable=invalid-name
@@ -44,7 +44,7 @@ class GmpModifyScanConfigTestMixin:
             warnings.simplefilter("always")
 
             self.gmp.modify_scan_config(
-                config_id='c1', selection=None, comment='foo'
+                config_id="c1", selection=None, comment="foo"
             )
 
             self.assertEqual(len(w), 1)
@@ -52,8 +52,8 @@ class GmpModifyScanConfigTestMixin:
 
         self.connection.send.has_been_called_with(
             '<modify_config config_id="c1">'
-            '<comment>foo</comment>'
-            '</modify_config>'
+            "<comment>foo</comment>"
+            "</modify_config>"
         )
 
     def test_modify_scan_config_set_nvt_pref(self):
@@ -62,7 +62,7 @@ class GmpModifyScanConfigTestMixin:
             warnings.simplefilter("always")
 
             self.gmp.modify_scan_config(
-                config_id='c1', selection='nvt_pref', nvt_oid='o1', name='foo'
+                config_id="c1", selection="nvt_pref", nvt_oid="o1", name="foo"
             )
 
             self.assertEqual(len(w), 1)
@@ -70,11 +70,11 @@ class GmpModifyScanConfigTestMixin:
 
         self.connection.send.has_been_called_with(
             '<modify_config config_id="c1">'
-            '<preference>'
+            "<preference>"
             '<nvt oid="o1"/>'
-            '<name>foo</name>'
-            '</preference>'
-            '</modify_config>'
+            "<name>foo</name>"
+            "</preference>"
+            "</modify_config>"
         )
 
     def test_modify_scan_config_set_scanner_pref(self):
@@ -83,7 +83,7 @@ class GmpModifyScanConfigTestMixin:
             warnings.simplefilter("always")
 
             self.gmp.modify_scan_config(
-                config_id='c1', selection='scan_pref', name='foo', value='bar'
+                config_id="c1", selection="scan_pref", name="foo", value="bar"
             )
 
             self.assertEqual(len(w), 1)
@@ -91,11 +91,11 @@ class GmpModifyScanConfigTestMixin:
 
         self.connection.send.has_been_called_with(
             '<modify_config config_id="c1">'
-            '<preference>'
-            '<name>foo</name>'
-            '<value>YmFy</value>'
-            '</preference>'
-            '</modify_config>'
+            "<preference>"
+            "<name>foo</name>"
+            "<value>YmFy</value>"
+            "</preference>"
+            "</modify_config>"
         )
 
     def test_modify_scan_config_set_nvt_selection(self):
@@ -104,10 +104,10 @@ class GmpModifyScanConfigTestMixin:
             warnings.simplefilter("always")
 
             self.gmp.modify_scan_config(
-                config_id='c1',
-                selection='nvt_selection',
-                nvt_oids=['o1'],
-                family='foo',
+                config_id="c1",
+                selection="nvt_selection",
+                nvt_oids=["o1"],
+                family="foo",
             )
 
             self.assertEqual(len(w), 1)
@@ -115,11 +115,11 @@ class GmpModifyScanConfigTestMixin:
 
         self.connection.send.has_been_called_with(
             '<modify_config config_id="c1">'
-            '<nvt_selection>'
-            '<family>foo</family>'
+            "<nvt_selection>"
+            "<family>foo</family>"
             '<nvt oid="o1"/>'
-            '</nvt_selection>'
-            '</modify_config>'
+            "</nvt_selection>"
+            "</modify_config>"
         )
 
     def test_modify_scan_config_set_family_selection(self):
@@ -128,9 +128,9 @@ class GmpModifyScanConfigTestMixin:
             warnings.simplefilter("always")
 
             self.gmp.modify_scan_config(
-                config_id='c1',
-                selection='family_selection',
-                families=[('foo', True, True)],
+                config_id="c1",
+                selection="family_selection",
+                families=[("foo", True, True)],
             )
 
             self.assertEqual(len(w), 1)
@@ -138,13 +138,13 @@ class GmpModifyScanConfigTestMixin:
 
         self.connection.send.has_been_called_with(
             '<modify_config config_id="c1">'
-            '<family_selection>'
-            '<growing>1</growing>'
-            '<family>'
-            '<name>foo</name>'
-            '<all>1</all>'
-            '<growing>1</growing>'
-            '</family>'
-            '</family_selection>'
-            '</modify_config>'
+            "<family_selection>"
+            "<growing>1</growing>"
+            "<family>"
+            "<name>foo</name>"
+            "<all>1</all>"
+            "<growing>1</growing>"
+            "</family>"
+            "</family_selection>"
+            "</modify_config>"
         )
