@@ -21,30 +21,30 @@ from gvm.errors import RequiredArgument
 
 class GmpModifyScanConfigSetNameTestMixin:
     def test_modify_scan_config_set_name(self):
-        self.gmp.modify_scan_config_set_name('c1', 'foo')
+        self.gmp.modify_scan_config_set_name("c1", "foo")
 
         self.connection.send.has_been_called_with(
             '<modify_config config_id="c1">'
-            '<name>foo</name>'
-            '</modify_config>'
+            "<name>foo</name>"
+            "</modify_config>"
         )
 
     def test_modify_scan_config_set_name_missing_config_id(self):
         with self.assertRaises(RequiredArgument):
-            self.gmp.modify_scan_config_set_name(config_id=None, name='name')
+            self.gmp.modify_scan_config_set_name(config_id=None, name="name")
 
         with self.assertRaises(RequiredArgument):
-            self.gmp.modify_scan_config_set_name('', name='name')
+            self.gmp.modify_scan_config_set_name("", name="name")
 
         with self.assertRaises(RequiredArgument):
-            self.gmp.modify_scan_config_set_name(config_id='', name='name')
+            self.gmp.modify_scan_config_set_name(config_id="", name="name")
 
     def test_modify_scan_config_set_name_missing_name(self):
         with self.assertRaises(RequiredArgument):
-            self.gmp.modify_scan_config_set_name(config_id='c', name='')
+            self.gmp.modify_scan_config_set_name(config_id="c", name="")
 
         with self.assertRaises(RequiredArgument):
-            self.gmp.modify_scan_config_set_name(config_id='c', name=None)
+            self.gmp.modify_scan_config_set_name(config_id="c", name=None)
 
         with self.assertRaises(RequiredArgument):
-            self.gmp.modify_scan_config_set_name('c', '')
+            self.gmp.modify_scan_config_set_name("c", "")
