@@ -21,4 +21,4 @@ class GmpSyncScanConfigTestMixin:
     def test_sync_scan_config(self):
         self.gmp.sync_scan_config()
 
-        self.connection.send.has_been_called_with('<sync_config/>')
+        self.connection.send.has_been_called_with("<sync_config/>")
