@@ -21,13 +21,13 @@ from gvm.errors import RequiredArgument
 
 class GmpGetCpeTestMixin:
     def test_get_cpe(self):
-        self.gmp.get_cpe(cpe_id='i1')
+        self.gmp.get_cpe(cpe_id="i1")
 
         self.connection.send.has_been_called_with(
             '<get_info info_id="i1" type="CPE" details="1"/>'
         )
 
-        self.gmp.get_cpe('i1')
+        self.gmp.get_cpe("i1")
 
         self.connection.send.has_been_called_with(
             '<get_info info_id="i1" type="CPE" details="1"/>'
@@ -35,10 +35,10 @@ class GmpGetCpeTestMixin:
 
     def test_get_cpe_missing_cpe_id(self):
         with self.assertRaises(RequiredArgument):
-            self.gmp.get_cpe(cpe_id='')
+            self.gmp.get_cpe(cpe_id="")
 
         with self.assertRaises(RequiredArgument):
-            self.gmp.get_cpe('')
+            self.gmp.get_cpe("")
 
         with self.assertRaises(RequiredArgument):
             self.gmp.get_cpe(cpe_id=None)
