@@ -24,21 +24,21 @@ class GmpGetCpeListTestMixin:
         self.connection.send.has_been_called_with('<get_info type="CPE"/>')
 
     def test_get_cpes_with_filter_string(self):
-        self.gmp.get_cpes(filter_string='foo=bar')
+        self.gmp.get_cpes(filter_string="foo=bar")
 
         self.connection.send.has_been_called_with(
             '<get_info type="CPE" filter="foo=bar"/>'
         )
 
     def test_get_cpes_with_filter_id(self):
-        self.gmp.get_cpes(filter_id='f1')
+        self.gmp.get_cpes(filter_id="f1")
 
         self.connection.send.has_been_called_with(
             '<get_info type="CPE" filt_id="f1"/>'
         )
 
     def test_get_cpes_with_name(self):
-        self.gmp.get_cpes(name='foo')
+        self.gmp.get_cpes(name="foo")
 
         self.connection.send.has_been_called_with(
             '<get_info type="CPE" name="foo"/>'
