@@ -24,21 +24,21 @@ class GmpGetCveListTestMixin:
         self.connection.send.has_been_called_with('<get_info type="CVE"/>')
 
     def test_get_cves_with_filter_string(self):
-        self.gmp.get_cves(filter_string='foo=bar')
+        self.gmp.get_cves(filter_string="foo=bar")
 
         self.connection.send.has_been_called_with(
             '<get_info type="CVE" filter="foo=bar"/>'
         )
 
     def test_get_cves_with_filter_id(self):
-        self.gmp.get_cves(filter_id='f1')
+        self.gmp.get_cves(filter_id="f1")
 
         self.connection.send.has_been_called_with(
             '<get_info type="CVE" filt_id="f1"/>'
         )
 
     def test_get_cves_with_name(self):
-        self.gmp.get_cves(name='foo')
+        self.gmp.get_cves(name="foo")
 
         self.connection.send.has_been_called_with(
             '<get_info type="CVE" name="foo"/>'
