@@ -26,21 +26,21 @@ class GmpGetDfnCertListTestMixin:
         )
 
     def test_get_cves_with_filter_string(self):
-        self.gmp.get_dfn_cert_advisories(filter_string='foo=bar')
+        self.gmp.get_dfn_cert_advisories(filter_string="foo=bar")
 
         self.connection.send.has_been_called_with(
             '<get_info type="DFN_CERT_ADV" filter="foo=bar"/>'
         )
 
     def test_get_cves_with_filter_id(self):
-        self.gmp.get_dfn_cert_advisories(filter_id='f1')
+        self.gmp.get_dfn_cert_advisories(filter_id="f1")
 
         self.connection.send.has_been_called_with(
             '<get_info type="DFN_CERT_ADV" filt_id="f1"/>'
         )
 
     def test_get_cves_with_name(self):
-        self.gmp.get_dfn_cert_advisories(name='foo')
+        self.gmp.get_dfn_cert_advisories(name="foo")
 
         self.connection.send.has_been_called_with(
             '<get_info type="DFN_CERT_ADV" name="foo"/>'
