@@ -21,17 +21,17 @@ class GmpGetTagsTestMixin:
     def test_get_tags(self):
         self.gmp.get_tags()
 
-        self.connection.send.has_been_called_with('<get_tags/>')
+        self.connection.send.has_been_called_with("<get_tags/>")
 
     def test_get_tags_with_filter_string(self):
-        self.gmp.get_tags(filter_string='foo=bar')
+        self.gmp.get_tags(filter_string="foo=bar")
 
         self.connection.send.has_been_called_with(
             '<get_tags filter="foo=bar"/>'
         )
 
     def test_get_tags_with_filter_id(self):
-        self.gmp.get_tags(filter_id='f1')
+        self.gmp.get_tags(filter_id="f1")
 
         self.connection.send.has_been_called_with('<get_tags filt_id="f1"/>')
 
