@@ -21,17 +21,17 @@ class GmpGetTargetsTestMixin:
     def test_get_targets(self):
         self.gmp.get_targets()
 
-        self.connection.send.has_been_called_with('<get_targets/>')
+        self.connection.send.has_been_called_with("<get_targets/>")
 
     def test_get_targets_with_filter_string(self):
-        self.gmp.get_targets(filter_string='foo=bar')
+        self.gmp.get_targets(filter_string="foo=bar")
 
         self.connection.send.has_been_called_with(
             '<get_targets filter="foo=bar"/>'
         )
 
     def test_get_targets_with_filter_id(self):
-        self.gmp.get_targets(filter_id='f1')
+        self.gmp.get_targets(filter_id="f1")
 
         self.connection.send.has_been_called_with('<get_targets filt_id="f1"/>')
 
