@@ -21,13 +21,13 @@ from gvm.errors import RequiredArgument
 
 class GmpCreateContainerTaskTestMixin:
     def test_create_task(self):
-        self.gmp.create_container_task(name='foo')
+        self.gmp.create_container_task(name="foo")
 
         self.connection.send.has_been_called_with(
-            '<create_task>'
-            '<name>foo</name>'
+            "<create_task>"
+            "<name>foo</name>"
             '<target id="0"/>'
-            '</create_task>'
+            "</create_task>"
         )
 
     def test_create_task_missing_name(self):
@@ -35,15 +35,15 @@ class GmpCreateContainerTaskTestMixin:
             self.gmp.create_container_task(name=None)
 
         with self.assertRaises(RequiredArgument):
-            self.gmp.create_container_task(name='')
+            self.gmp.create_container_task(name="")
 
     def test_create_task_with_comment(self):
-        self.gmp.create_container_task(name='foo', comment='bar')
+        self.gmp.create_container_task(name="foo", comment="bar")
 
         self.connection.send.has_been_called_with(
-            '<create_task>'
-            '<name>foo</name>'
+            "<create_task>"
+            "<name>foo</name>"
             '<target id="0"/>'
-            '<comment>bar</comment>'
-            '</create_task>'
+            "<comment>bar</comment>"
+            "</create_task>"
         )
