@@ -21,12 +21,12 @@ from gvm.errors import GvmError
 
 class GmpMoveTaskTestMixin:
     def test_move_task(self):
-        self.gmp.move_task('a1')
+        self.gmp.move_task("a1")
 
         self.connection.send.has_been_called_with('<move_task task_id="a1"/>')
 
     def test_move_task_to_slave(self):
-        self.gmp.move_task('a1', slave_id='s1')
+        self.gmp.move_task("a1", slave_id="s1")
 
         self.connection.send.has_been_called_with(
             '<move_task task_id="a1" slave_id="s1"/>'
@@ -37,4 +37,4 @@ class GmpMoveTaskTestMixin:
             self.gmp.move_task(None)
 
         with self.assertRaises(GvmError):
-            self.gmp.move_task('')
+            self.gmp.move_task("")
