@@ -21,15 +21,15 @@ from gvm.errors import RequiredArgument
 
 class GmpCloneUserTestMixin:
     def test_clone(self):
-        self.gmp.clone_user('a1')
+        self.gmp.clone_user("a1")
 
         self.connection.send.has_been_called_with(
-            '<create_user>' '<copy>a1</copy>' '</create_user>'
+            "<create_user>" "<copy>a1</copy>" "</create_user>"
         )
 
     def test_missing_id(self):
         with self.assertRaises(RequiredArgument):
-            self.gmp.clone_user('')
+            self.gmp.clone_user("")
 
         with self.assertRaises(RequiredArgument):
             self.gmp.clone_user(None)
