@@ -21,11 +21,11 @@ from gvm.errors import RequiredArgument
 
 class GmpGetVulnerabilityTestMixin:
     def test_get_vulnerability(self):
-        self.gmp.get_vulnerability('a1')
+        self.gmp.get_vulnerability("a1")
 
         self.connection.send.has_been_called_with('<get_vulns vuln_id="a1"/>')
 
-        self.gmp.get_vulnerability(vulnerability_id='a1')
+        self.gmp.get_vulnerability(vulnerability_id="a1")
 
         self.connection.send.has_been_called_with('<get_vulns vuln_id="a1"/>')
 
@@ -34,4 +34,4 @@ class GmpGetVulnerabilityTestMixin:
             self.gmp.get_vulnerability(vulnerability_id=None)
 
         with self.assertRaises(RequiredArgument):
-            self.gmp.get_vulnerability(vulnerability_id='')
+            self.gmp.get_vulnerability(vulnerability_id="")
