@@ -22,30 +22,30 @@ from gvm.errors import RequiredArgument
 class GmpAuthenticateTestMixin:
     def test_missing_username(self):
         with self.assertRaises(RequiredArgument):
-            self.gmp.authenticate(None, 'foo')
+            self.gmp.authenticate(None, "foo")
 
         with self.assertRaises(RequiredArgument):
-            self.gmp.authenticate('', 'foo')
+            self.gmp.authenticate("", "foo")
 
     def test_missing_password(self):
         with self.assertRaises(RequiredArgument):
-            self.gmp.authenticate('bar', None)
+            self.gmp.authenticate("bar", None)
 
         with self.assertRaises(RequiredArgument):
-            self.gmp.authenticate('bar', '')
+            self.gmp.authenticate("bar", "")
 
     def test_authentication_success(self):
         self.assertFalse(self.gmp.is_authenticated())
 
-        self.gmp.authenticate('foo', 'bar')
+        self.gmp.authenticate("foo", "bar")
 
         self.connection.send.has_been_called_with(
-            '<authenticate>'
-            '<credentials>'
-            '<username>foo</username>'
-            '<password>bar</password>'
-            '</credentials>'
-            '</authenticate>'
+            "<authenticate>"
+            "<credentials>"
+            "<username>foo</username>"
+            "<password>bar</password>"
+            "</credentials>"
+            "</authenticate>"
         )
 
         self.assertTrue(self.gmp.is_authenticated())
@@ -57,15 +57,15 @@ class GmpAuthenticateTestMixin:
 
         self.assertFalse(self.gmp.is_authenticated())
 
-        self.gmp.authenticate('foo', 'bar')
+        self.gmp.authenticate("foo", "bar")
 
         self.connection.send.has_been_called_with(
-            '<authenticate>'
-            '<credentials>'
-            '<username>foo</username>'
-            '<password>bar</password>'
-            '</credentials>'
-            '</authenticate>'
+            "<authenticate>"
+            "<credentials>"
+            "<username>foo</username>"
+            "<password>bar</password>"
+            "</credentials>"
+            "</authenticate>"
         )
 
         self.assertFalse(self.gmp.is_authenticated())
