@@ -17,10 +17,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from ...gmpv208 import Gmpv208TestCase
-from .feed import (
-    GmpGetFeedsTestMixin,
-    GmpGetFeedTestMixin,
-)
+from .feed import GmpGetFeedsTestMixin, GmpGetFeedTestMixin
 
 
 class Gmpv208GetFeedTestCase(GmpGetFeedTestMixin, Gmpv208TestCase):
