@@ -17,9 +17,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from ...gmpv208 import Gmpv208TestCase
-from .help import (
-    GmpHelpTestMixin,
-)
+from .help import GmpHelpTestMixin
 
 
 class Gmpv208HelpTestCase(GmpHelpTestMixin, Gmpv208TestCase):
