@@ -17,10 +17,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from ...gmpv208 import Gmpv208TestCase
-from .trashcan import (
-    GmpEmptyTrashcanTestMixin,
-    GmpRestoreFromTrashcanTestMixin,
-)
+from .trashcan import GmpEmptyTrashcanTestMixin, GmpRestoreFromTrashcanTestMixin
 
 
 class Gmpv208EmptyTrashcanTestCase(GmpEmptyTrashcanTestMixin, Gmpv208TestCase):
