@@ -16,112 +16,111 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from gvm.errors import RequiredArgument, InvalidArgumentType
-
+from gvm.errors import InvalidArgumentType, RequiredArgument
 from gvm.protocols.gmpv214 import ScannerType
 
 
 class GmpCreateScannerTestMixin:
     def test_create_scanner(self):
         self.gmp.create_scanner(
-            name='foo',
-            host='localhost',
+            name="foo",
+            host="localhost",
             port=1234,
             scanner_type=ScannerType.OSP_SCANNER_TYPE,
-            credential_id='c1',
+            credential_id="c1",
         )
 
         self.connection.send.has_been_called_with(
-            '<create_scanner>'
-            '<name>foo</name>'
-            '<host>localhost</host>'
-            '<port>1234</port>'
-            '<type>1</type>'
+            "<create_scanner>"
+            "<name>foo</name>"
+            "<host>localhost</host>"
+            "<port>1234</port>"
+            "<type>1</type>"
             '<credential id="c1"/>'
-            '</create_scanner>'
+            "</create_scanner>"
         )
 
     def test_create_scanner_missing_name(self):
         with self.assertRaises(RequiredArgument):
             self.gmp.create_scanner(
                 name=None,
-                host='localhost',
+                host="localhost",
                 port=1234,
                 scanner_type=ScannerType.OSP_SCANNER_TYPE,
-                credential_id='c1',
+                credential_id="c1",
             )
 
         with self.assertRaises(RequiredArgument):
             self.gmp.create_scanner(
-                name='',
-                host='localhost',
+                name="",
+                host="localhost",
                 port=1234,
-                scanner_type='1',
-                credential_id='c1',
+                scanner_type="1",
+                credential_id="c1",
             )
 
     def test_create_scanner_missing_host(self):
         with self.assertRaises(RequiredArgument):
             self.gmp.create_scanner(
-                name='foo',
+                name="foo",
                 host=None,
                 port=1234,
                 scanner_type=ScannerType.OSP_SCANNER_TYPE,
-                credential_id='c1',
+                credential_id="c1",
             )
 
         with self.assertRaises(RequiredArgument):
             self.gmp.create_scanner(
-                name='foo',
-                host='',
+                name="foo",
+                host="",
                 port=1234,
                 scanner_type=ScannerType.OSP_SCANNER_TYPE,
-                credential_id='c1',
+                credential_id="c1",
             )
 
     def test_create_scanner_missing_port(self):
         with self.assertRaises(RequiredArgument):
             self.gmp.create_scanner(
-                name='foo',
-                host='localhost',
+                name="foo",
+                host="localhost",
                 port=None,
                 scanner_type=ScannerType.OSP_SCANNER_TYPE,
-                credential_id='c1',
+                credential_id="c1",
             )
 
         with self.assertRaises(RequiredArgument):
             self.gmp.create_scanner(
-                name='foo',
-                host='localhost',
-                port='',
+                name="foo",
+                host="localhost",
+                port="",
                 scanner_type=ScannerType.OSP_SCANNER_TYPE,
-                credential_id='c1',
+                credential_id="c1",
             )
 
     def test_create_scanner_missing_scanner_type(self):
         with self.assertRaises(RequiredArgument):
             self.gmp.create_scanner(
-                name='foo',
-                host='localhost',
+                name="foo",
+                host="localhost",
                 port=1234,
                 scanner_type=None,
-                credential_id='c1',
+                credential_id="c1",
             )
 
         with self.assertRaises(RequiredArgument):
             self.gmp.create_scanner(
-                name='foo',
-                host='localhost',
+                name="foo",
+                host="localhost",
                 port=1234,
-                scanner_type='',
-                credential_id='c1',
+                scanner_type="",
+                credential_id="c1",
             )
 
     def test_create_scanner_missing_credential_id(self):
         with self.assertRaises(RequiredArgument):
             self.gmp.create_scanner(
-                name='foo',
-                host='localhost',
+                name="foo",
+                host="localhost",
                 port=1234,
                 scanner_type=ScannerType.OSP_SCANNER_TYPE,
                 credential_id=None,
@@ -129,79 +128,79 @@ class GmpCreateScannerTestMixin:
 
         with self.assertRaises(RequiredArgument):
             self.gmp.create_scanner(
-                name='foo',
-                host='localhost',
+                name="foo",
+                host="localhost",
                 port=1234,
                 scanner_type=ScannerType.OSP_SCANNER_TYPE,
-                credential_id='',
+                credential_id="",
             )
 
     def test_create_scanner_invalid_scanner_type(self):
         with self.assertRaises(InvalidArgumentType):
             self.gmp.create_scanner(
-                name='foo',
-                host='localhost',
+                name="foo",
+                host="localhost",
                 port=1234,
-                scanner_type='bar',
-                credential_id='c1',
+                scanner_type="bar",
+                credential_id="c1",
             )
 
         with self.assertRaises(AttributeError):
             self.gmp.create_scanner(
-                name='foo',
-                host='localhost',
+                name="foo",
+                host="localhost",
                 port=1234,
                 scanner_type=ScannerType.GMP_SCANNER_TYPE,  # pylint: disable=no-member
-                credential_id='c1',
+                credential_id="c1",
             )
 
         with self.assertRaises(InvalidArgumentType):
             self.gmp.create_scanner(
-                name='foo',
-                host='localhost',
+                name="foo",
+                host="localhost",
                 port=1234,
-                scanner_type='55',
-                credential_id='c1',
+                scanner_type="55",
+                credential_id="c1",
             )
 
     def test_create_scanner_with_ca_pub(self):
         self.gmp.create_scanner(
-            name='foo',
-            host='localhost',
+            name="foo",
+            host="localhost",
             port=1234,
-            ca_pub='foo',
+            ca_pub="foo",
             scanner_type=ScannerType.OSP_SCANNER_TYPE,
-            credential_id='c1',
+            credential_id="c1",
         )
 
         self.connection.send.has_been_called_with(
-            '<create_scanner>'
-            '<name>foo</name>'
-            '<host>localhost</host>'
-            '<port>1234</port>'
-            '<type>1</type>'
-            '<ca_pub>foo</ca_pub>'
+            "<create_scanner>"
+            "<name>foo</name>"
+            "<host>localhost</host>"
+            "<port>1234</port>"
+            "<type>1</type>"
+            "<ca_pub>foo</ca_pub>"
             '<credential id="c1"/>'
-            '</create_scanner>'
+            "</create_scanner>"
         )
 
     def test_create_scanner_with_comment(self):
         self.gmp.create_scanner(
-            name='foo',
-            host='localhost',
+            name="foo",
+            host="localhost",
             port=1234,
             scanner_type=ScannerType.OSP_SCANNER_TYPE,
-            credential_id='c1',
-            comment='bar',
+            credential_id="c1",
+            comment="bar",
         )
 
         self.connection.send.has_been_called_with(
-            '<create_scanner>'
-            '<name>foo</name>'
-            '<host>localhost</host>'
-            '<port>1234</port>'
-            '<type>1</type>'
+            "<create_scanner>"
+            "<name>foo</name>"
+            "<host>localhost</host>"
+            "<port>1234</port>"
+            "<type>1</type>"
             '<credential id="c1"/>'
-            '<comment>bar</comment>'
-            '</create_scanner>'
+            "<comment>bar</comment>"
+            "</create_scanner>"
         )
