@@ -25,26 +25,26 @@ from gvm.protocols.gmpv214 import PermissionSubjectType
 class GetPermissionSubjectTypeFromStringTestCase(unittest.TestCase):
     def test_invalid(self):
         with self.assertRaises(InvalidArgument):
-            PermissionSubjectType.from_string('foo')
+            PermissionSubjectType.from_string("foo")
 
     def test_none_or_empty(self):
         ct = PermissionSubjectType.from_string(None)
         self.assertIsNone(ct)
-        ct = PermissionSubjectType.from_string('')
+        ct = PermissionSubjectType.from_string("")
         self.assertIsNone(ct)
 
     def test_user(self):
-        ct = PermissionSubjectType.from_string('user')
+        ct = PermissionSubjectType.from_string("user")
         self.assertEqual(ct, PermissionSubjectType.USER)
 
     def test_role(self):
-        ct = PermissionSubjectType.from_string('role')
+        ct = PermissionSubjectType.from_string("role")
         self.assertEqual(ct, PermissionSubjectType.ROLE)
 
     def test_group(self):
-        ct = PermissionSubjectType.from_string('group')
+        ct = PermissionSubjectType.from_string("group")
         self.assertEqual(ct, PermissionSubjectType.GROUP)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
