@@ -19,155 +19,154 @@
 from decimal import Decimal
 
 from gvm.errors import InvalidArgument, RequiredArgument
-
 from gvm.protocols.gmpv224 import SeverityLevel
 
 
 class GmpModifyNoteTestMixin:
     def test_modify_note(self):
-        self.gmp.modify_note(note_id='n1', text='foo')
+        self.gmp.modify_note(note_id="n1", text="foo")
 
         self.connection.send.has_been_called_with(
-            '<modify_note note_id="n1">' '<text>foo</text>' '</modify_note>'
+            '<modify_note note_id="n1">' "<text>foo</text>" "</modify_note>"
         )
 
     def test_modify_note_missing_note_id(self):
         with self.assertRaises(RequiredArgument):
-            self.gmp.modify_note(note_id=None, text='foo')
+            self.gmp.modify_note(note_id=None, text="foo")
 
         with self.assertRaises(RequiredArgument):
-            self.gmp.modify_note(note_id='', text='foo')
+            self.gmp.modify_note(note_id="", text="foo")
 
         with self.assertRaises(RequiredArgument):
-            self.gmp.modify_note('', text='foo')
+            self.gmp.modify_note("", text="foo")
 
     def test_modify_note_missing_text(self):
         with self.assertRaises(RequiredArgument):
-            self.gmp.modify_note(note_id='n1', text='')
+            self.gmp.modify_note(note_id="n1", text="")
 
         with self.assertRaises(RequiredArgument):
-            self.gmp.modify_note(note_id='n1', text=None)
+            self.gmp.modify_note(note_id="n1", text=None)
 
         with self.assertRaises(RequiredArgument):
-            self.gmp.modify_note('n1', '')
+            self.gmp.modify_note("n1", "")
 
     def test_modify_note_with_days_active(self):
-        self.gmp.modify_note(note_id='n1', text='foo', days_active=0)
+        self.gmp.modify_note(note_id="n1", text="foo", days_active=0)
 
         self.connection.send.has_been_called_with(
             '<modify_note note_id="n1">'
-            '<text>foo</text>'
-            '<active>0</active>'
-            '</modify_note>'
+            "<text>foo</text>"
+            "<active>0</active>"
+            "</modify_note>"
         )
 
-        self.gmp.modify_note(note_id='n1', text='foo', days_active=-1)
+        self.gmp.modify_note(note_id="n1", text="foo", days_active=-1)
 
         self.connection.send.has_been_called_with(
             '<modify_note note_id="n1">'
-            '<text>foo</text>'
-            '<active>-1</active>'
-            '</modify_note>'
+            "<text>foo</text>"
+            "<active>-1</active>"
+            "</modify_note>"
         )
 
-        self.gmp.modify_note(note_id='n1', text='foo', days_active=600)
+        self.gmp.modify_note(note_id="n1", text="foo", days_active=600)
 
         self.connection.send.has_been_called_with(
             '<modify_note note_id="n1">'
-            '<text>foo</text>'
-            '<active>600</active>'
-            '</modify_note>'
+            "<text>foo</text>"
+            "<active>600</active>"
+            "</modify_note>"
         )
 
     def test_modify_note_with_port(self):
-        self.gmp.modify_note(note_id='n1', text='foo', port='123/tcp')
+        self.gmp.modify_note(note_id="n1", text="foo", port="123/tcp")
 
         self.connection.send.has_been_called_with(
             '<modify_note note_id="n1">'
-            '<text>foo</text>'
-            '<port>123/tcp</port>'
-            '</modify_note>'
+            "<text>foo</text>"
+            "<port>123/tcp</port>"
+            "</modify_note>"
         )
 
     def test_modify_note_with_hosts(self):
-        self.gmp.modify_note(note_id='n1', text='foo', hosts=['foo'])
+        self.gmp.modify_note(note_id="n1", text="foo", hosts=["foo"])
 
         self.connection.send.has_been_called_with(
             '<modify_note note_id="n1">'
-            '<text>foo</text>'
-            '<hosts>foo</hosts>'
-            '</modify_note>'
+            "<text>foo</text>"
+            "<hosts>foo</hosts>"
+            "</modify_note>"
         )
 
-        self.gmp.modify_note(note_id='n1', text='foo', hosts=['foo', 'bar'])
+        self.gmp.modify_note(note_id="n1", text="foo", hosts=["foo", "bar"])
 
         self.connection.send.has_been_called_with(
             '<modify_note note_id="n1">'
-            '<text>foo</text>'
-            '<hosts>foo,bar</hosts>'
-            '</modify_note>'
+            "<text>foo</text>"
+            "<hosts>foo,bar</hosts>"
+            "</modify_note>"
         )
 
     def test_modify_note_with_result_id(self):
-        self.gmp.modify_note(note_id='n1', text='foo', result_id='r1')
+        self.gmp.modify_note(note_id="n1", text="foo", result_id="r1")
 
         self.connection.send.has_been_called_with(
             '<modify_note note_id="n1">'
-            '<text>foo</text>'
+            "<text>foo</text>"
             '<result id="r1"/>'
-            '</modify_note>'
+            "</modify_note>"
         )
 
     def test_modify_note_with_task_id(self):
-        self.gmp.modify_note(note_id='n1', text='foo', task_id='r1')
+        self.gmp.modify_note(note_id="n1", text="foo", task_id="r1")
 
         self.connection.send.has_been_called_with(
             '<modify_note note_id="n1">'
-            '<text>foo</text>'
+            "<text>foo</text>"
             '<task id="r1"/>'
-            '</modify_note>'
+            "</modify_note>"
         )
 
     def test_modify_note_with_severity(self):
-        self.gmp.modify_note(note_id='n1', text='foo', severity='5.5')
+        self.gmp.modify_note(note_id="n1", text="foo", severity="5.5")
 
         self.connection.send.has_been_called_with(
             '<modify_note note_id="n1">'
-            '<text>foo</text>'
-            '<severity>5.5</severity>'
-            '</modify_note>'
+            "<text>foo</text>"
+            "<severity>5.5</severity>"
+            "</modify_note>"
         )
 
-        self.gmp.modify_note(note_id='n1', text='foo', severity=5.5)
+        self.gmp.modify_note(note_id="n1", text="foo", severity=5.5)
 
         self.connection.send.has_been_called_with(
             '<modify_note note_id="n1">'
-            '<text>foo</text>'
-            '<severity>5.5</severity>'
-            '</modify_note>'
+            "<text>foo</text>"
+            "<severity>5.5</severity>"
+            "</modify_note>"
         )
 
-        self.gmp.modify_note(note_id='n1', text='foo', severity=Decimal(5.5))
+        self.gmp.modify_note(note_id="n1", text="foo", severity=Decimal(5.5))
 
         self.connection.send.has_been_called_with(
             '<modify_note note_id="n1">'
-            '<text>foo</text>'
-            '<severity>5.5</severity>'
-            '</modify_note>'
+            "<text>foo</text>"
+            "<severity>5.5</severity>"
+            "</modify_note>"
         )
 
     def test_modify_note_with_threat(self):
         self.gmp.modify_note(
-            note_id='n1', text='foo', threat=SeverityLevel.HIGH
+            note_id="n1", text="foo", threat=SeverityLevel.HIGH
         )
 
         self.connection.send.has_been_called_with(
-            '<modify_note note_id="n1">' '<text>foo</text>' '</modify_note>'
+            '<modify_note note_id="n1">' "<text>foo</text>" "</modify_note>"
         )
 
     def test_modify_note_with_invalid_port(self):
         with self.assertRaises(InvalidArgument):
-            self.gmp.modify_note(note_id='o1', text='foo', port='123')
+            self.gmp.modify_note(note_id="o1", text="foo", port="123")
 
         with self.assertRaises(InvalidArgument):
-            self.gmp.modify_note(note_id='o1', text='foo', port='tcp/123')
+            self.gmp.modify_note(note_id="o1", text="foo", port="tcp/123")
