@@ -16,11 +16,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+from ...gmpv208.system.feed import GmpGetFeedsTestMixin, GmpGetFeedTestMixin
 from ...gmpv224 import Gmpv224TestCase
-from ...gmpv208.system.feed import (
-    GmpGetFeedsTestMixin,
-    GmpGetFeedTestMixin,
-)
 
 
 class Gmpv224GetFeedTestCase(GmpGetFeedTestMixin, Gmpv224TestCase):
