@@ -31,8 +31,8 @@ class OSPGetVersionTestCase(unittest.TestCase):
     def test_get_version(self):
         self.osp.get_version()
 
-        self.connection.send.has_been_called_with('<get_version/>')
+        self.connection.send.has_been_called_with("<get_version/>")
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
