@@ -38,8 +38,8 @@ class OSPGetVtsTestCase(unittest.TestCase):
     def test_get_vts(self):
         self.osp.get_vts()
 
-        self.connection.send.has_been_called_with('<get_vts/>')
+        self.connection.send.has_been_called_with("<get_vts/>")
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
